@@ -130,8 +130,7 @@ def update(client, config):
     if config.payload:
         logger.debug('Uploading a payload. Bypassing rules update.')
         return
-    if not config.core_collect:
-        client.update_rules()
+    client.update_rules()
 
 
 @phase
@@ -183,6 +182,10 @@ def post_update(client, config):
             logger.debug('Running client in offline mode. Bypassing registration.')
             return
 
+        if config.no_upload:
+            logger.debug("Running client without uploading. Bypassing registration.")
+            return
+
         if config.display_name and not config.register:
             # setting display name independent of registration
             if client.set_display_name(config.display_name):
@@ -212,6 +215,10 @@ def post_update(client, config):
         logger.debug('Running client in offline mode. Bypassing registration.')
         return
 
+    if config.no_upload:
+        logger.debug("Running client without uploading. Bypassing registration.")
+        return
+
     # --payload short circuits registration check
     if config.payload:
         logger.debug('Uploading a specified archive. Bypassing registration.')
