@@ -89,14 +89,13 @@ class HumanReadableFormat(Formatter):
             missing=False,
             tracebacks=False,
             dropped=False,
-            fail_only=False,
+            show_rules=None,
             stream=sys.stdout):
-        self.broker = broker
+        super(HumanReadableFormat, self).__init__(broker, stream=stream)
         self.missing = missing
         self.tracebacks = tracebacks
         self.dropped = dropped
-        self.fail_only = fail_only
-        self.stream = stream
+        self.show_rules = [] if show_rules is None else show_rules
 
     def print_header(self, header, color):
         ln = len(header)
@@ -107,15 +106,15 @@ class HumanReadableFormat(Formatter):
     def preprocess(self):
         response = namedtuple('response', 'color label intl title')
         self.responses = {
+            'skip': response(color=Fore.BLUE, label="SKIP", intl='S', title="Missing Deps: "),
             'pass': response(color=Fore.GREEN, label="PASS", intl='P', title="Passed      : "),
             'rule': response(color=Fore.RED, label="FAIL", intl='F', title="Failed      : "),
             'info': response(color=Fore.WHITE, label="INFO", intl='I', title="Info        : "),
-            'skip': response(color=Fore.BLUE, label="SKIP", intl='S', title="Missing Deps: "),
-            'fingerprint': response(color=Fore.YELLOW, label="FINGERPRINT", intl='P',
-                                  title="Fingerprint : "),
+            'none': response(color=Fore.BLUE, label="RETURNED NONE", intl='N', title="Ret'd None  : "),
             'metadata': response(color=Fore.YELLOW, label="META", intl='M', title="Metadata    : "),
             'metadata_key': response(color=Fore.MAGENTA, label="META", intl='K', title="Metadata Key: "),
-            'exception': response(color=Fore.RED, label="EXCEPT", intl='E', title="Exceptions  : ")
+            'fingerprint': response(color=Fore.YELLOW, label="FINGERPRINT", intl='P', title="Fingerprint : "),
+            'exception': response(color=Fore.RED, label="EXCEPT", intl='E', title="Exceptions  : "),
         }
 
         self.counts = {}
@@ -177,19 +176,27 @@ class HumanReadableFormat(Formatter):
             name = "%s%s%s" % (resp.color, name, Style.RESET_ALL)
             print(name, file=self.stream)
             print(underline, file=self.stream)
-            print(render_links(c), file=self.stream)
-            print(render(c, v), file=self.stream)
+            if v.get('type') != 'none':
+                print(render_links(c), file=self.stream)
+                print(render(c, v), file=self.stream)
             print(file=self.stream)
 
         for c in sorted(self.broker.get_by_type(rule), key=dr.get_name):
             v = self.broker[c]
             _type = v.get('type')
+            if _type is None:
+                continue
+
             if _type in self.responses:
                 self.counts[_type] += 1
-            if (_type and ((self.fail_only and _type == 'rule') or
-                           ((self.missing and _type == 'skip') or
-                            (not self.fail_only and _type != 'skip')))):
+
+            if (
+                    (self.missing and _type == 'skip') or
+                    (self.show_rules and _type in self.show_rules) or
+                    (not self.show_rules and _type not in ['skip', 'none'])
+            ):
                 printit(c, v)
+
         print(file=self.stream)
 
         self.print_header("Rule Execution Summary", Fore.CYAN)
@@ -213,24 +220,39 @@ class HumanReadableFormatAdapter(FormatterAdapter):
 
     @staticmethod
     def configure(p):
-        p.add_argument("-m", "--missing", help="Show missing requirements.", action="store_true")
         p.add_argument("-t", "--tracebacks", help="Show stack traces.", action="store_true")
         p.add_argument("-d", "--dropped", help="Show collected files that weren't processed.", action="store_true")
-        p.add_argument("-F", "--fail-only", help="Show FAIL results only. Conflict with '-m' or '-f', will be dropped when using them together", action="store_true")
+        p.add_argument("-m", "--missing", help="Show missing requirements.", action="store_true")
+        p.add_argument("-S", "--show-rules", default=[], nargs="+",
+                       choices=["fail", "info", "pass", "none", "metadata", "fingerprint"],
+                       metavar="TYPE",
+                       help="Show results per rule's type: 'fail', 'info', 'pass', 'none', 'metadata', and 'fingerprint'")
+        p.add_argument("-F", "--fail-only",
+                       help="Show FAIL results only. Conflict with '-m', will be dropped when using them together. This option is deprecated by '-S fail'",
+                       action="store_true")
 
-    def __init__(self, args):
-        self.missing = args.missing
+    def __init__(self, args=None):
         self.tracebacks = args.tracebacks
         self.dropped = args.dropped
-        self.fail_only = args.fail_only
-        self.formatter = None
-        if self.missing and self.fail_only:
+        self.missing = args.missing
+        fail_only = args.fail_only
+        if self.missing and fail_only:
             print(Fore.YELLOW + 'Options conflict: -m and -F, drops -F', file=sys.stderr)
-            self.fail_only = False
+            fail_only = None
+        self.show_rules = []  # Empty by default, means show ALL types (excludes "none")
+        if not args.show_rules and fail_only:
+            self.show_rules = ['rule']
+        elif args.show_rules:
+            self.show_rules = [opt.replace('fail', 'rule') for opt in args.show_rules]
 
     def preprocess(self, broker):
-        self.formatter = HumanReadableFormat(broker,
-                self.missing, self.tracebacks, self.dropped, self.fail_only)
+        self.formatter = HumanReadableFormat(
+            broker,
+            self.missing,
+            self.tracebacks,
+            self.dropped,
+            self.show_rules,
+        )
         self.formatter.preprocess()
 
     def postprocess(self, broker):
