@@ -5,7 +5,6 @@ class Specs(SpecSet):
     abrt_ccpp_conf = RegistryPoint(filterable=True)
     abrt_status_bare = RegistryPoint()
     alternatives_display_python = RegistryPoint()
-    ansible_tower_settings = RegistryPoint(filterable=True, multi_output=True)
     amq_broker = RegistryPoint(multi_output=True)
     ansible_host = RegistryPoint()
     auditctl_status = RegistryPoint()
@@ -97,6 +96,7 @@ class Specs(SpecSet):
     crypto_policies_opensshserver = RegistryPoint()
     crypto_policies_bind = RegistryPoint()
     crt = RegistryPoint()
+    cups_ppd = RegistryPoint(multi_output=True)
     current_clocksource = RegistryPoint()
     date_iso = RegistryPoint()
     date = RegistryPoint()
@@ -294,7 +294,9 @@ class Specs(SpecSet):
     locale = RegistryPoint()
     localtime = RegistryPoint()
     logrotate_conf = RegistryPoint(multi_output=True)
+    lpfc_max_luns = RegistryPoint()
     lpstat_p = RegistryPoint()
+    lpstat_protocol_printers = RegistryPoint()
     ls_boot = RegistryPoint()
     ls_dev = RegistryPoint()
     ls_disk = RegistryPoint()
@@ -516,6 +518,7 @@ class Specs(SpecSet):
     pvs = RegistryPoint()
     qemu_conf = RegistryPoint()
     qemu_xml = RegistryPoint(multi_output=True)
+    ql2xmaxlun = RegistryPoint()
     qpid_stat_g = RegistryPoint()
     qpid_stat_q = RegistryPoint()
     qpid_stat_u = RegistryPoint()
@@ -555,6 +558,7 @@ class Specs(SpecSet):
     rhsm_releasever = RegistryPoint()
     rndc_status = RegistryPoint()
     root_crontab = RegistryPoint()
+    ros_config = RegistryPoint()
     route = RegistryPoint()
     rpm_ostree_status = RegistryPoint()
     rpm_V_packages = RegistryPoint()
@@ -575,12 +579,14 @@ class Specs(SpecSet):
     satellite_custom_ca_chain = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
     satellite_non_yum_type_repos = RegistryPoint()
+    satellite_sca_status = RegistryPoint()
     satellite_settings = RegistryPoint()
     satellite_version_rb = RegistryPoint()
     satellite_custom_hiera = RegistryPoint()
     scheduler = RegistryPoint(multi_output=True)
     sched_rt_runtime_us = RegistryPoint()
     scsi = RegistryPoint()
+    scsi_mod_max_report_luns = RegistryPoint()
     scsi_mod_use_blk_mq = RegistryPoint()
     sctp_asc = RegistryPoint()
     sctp_eps = RegistryPoint()
@@ -721,6 +727,7 @@ class Specs(SpecSet):
     yum_repolist = RegistryPoint()
     yum_repos_d = RegistryPoint(multi_output=True)
     yum_updateinfo = RegistryPoint()
+    yum_updates = RegistryPoint()
     zdump_v = RegistryPoint()
     zipl_conf = RegistryPoint()
     sendq_socket_buffer = RegistryPoint()
